import { overrideConfig, fetchReadme, decodeParams } from "../utils/queries.mjs";
import { addPrerenderPath } from "../utils/prerender.mjs";
import { parseContent } from "#content/server";
import * as imports from "#imports";
const moduleConfig = imports.useRuntimeConfig().github;
let handler;
if (process.env.NODE_ENV === "development" || moduleConfig.disableCache) {
  handler = imports.defineEventHandler;
} else {
  handler = imports.defineCachedEventHandler;
}
export default handler(
  async (event) => {
    addPrerenderPath(event);
    const query = decodeParams(event.context.params.query);
    const githubConfig = overrideConfig(moduleConfig, query);
    if (!githubConfig.owner || !githubConfig.repo || !githubConfig.api) {
      return [];
    }
    const readme = await fetchReadme(githubConfig);
    const content = Buffer.from(readme.content, "base64").toString();
    if (moduleConfig.parseContents) {
      return await parseContent(`${githubConfig.owner}:${githubConfig.repo}:readme.md`, content, {
        markdown: {
          remarkPlugins: {
            "remark-github": {
              repository: `${githubConfig.owner}/${githubConfig.repo}`
            }
          }
        }
      });
    }
    return content;
  },
  {
    maxAge: 60
  }
);
