import { decodeParams, fetchReleases, overrideConfig, parseRelease } from "../../utils/queries.mjs";
import { addPrerenderPath } from "../../utils/prerender.mjs";
import * as imports from "#imports";
const moduleConfig = imports.useRuntimeConfig().github;
let handler;
if (process.env.NODE_ENV === "development" || moduleConfig.disableCache) {
  handler = imports.defineEventHandler;
} else {
  handler = imports.defineCachedEventHandler;
}
export default handler(
  async (event) => {
    addPrerenderPath(event);
    const query = decodeParams(event.context.params.query);
    const githubConfig = overrideConfig(moduleConfig, query);
    if (!githubConfig.owner || !githubConfig.repo || !githubConfig.api) {
      return [];
    }
    let releases = await fetchReleases(query, githubConfig);
    if (!releases) {
      return;
    }
    if (moduleConfig.parseContents) {
      if (Array.isArray(releases)) {
        releases = await Promise.all(releases.map((release) => parseRelease(release, githubConfig)));
      } else {
        return await parseRelease(releases, githubConfig);
      }
    }
    return (releases || []).sort((a, b) => a.v !== b.v ? b.v - a.v : a.date - b.date).filter(Boolean);
  },
  {
    maxAge: 60
  }
);
